@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2019 Red Hat.
+ * Copyright (c) 2012-2020 Red Hat.
  * Copyright (c) 1997,2004 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This library is free software; you can redistribute it and/or modify it
@@ -263,7 +263,7 @@ PCP_CALL extern int pmTrimNameSpace(void);
 /*
  * Expand a list of names to a list of metrics ids
  */
-PCP_CALL extern int pmLookupName(int, char **, pmID *);
+PCP_CALL extern int pmLookupName(int, const char **, pmID *);
 
 /*
  * Find the names of descendent nodes in the PMNS
@@ -988,6 +988,19 @@ PCP_CALL extern int pmLoadDerivedConfig(const char *);
 PCP_CALL extern int pmRegisterDerivedMetric(const char *, const char *, char **);
 PCP_CALL extern char *pmRegisterDerived(const char *, const char *);
 PCP_CALL extern char *pmDerivedErrStr(void);
+PCP_CALL extern int pmAddDerivedMetric(const char *, const char *, char **);
+PCP_CALL extern char *pmAddDerived(const char *, const char *);
+PCP_CALL extern int pmGetDerivedControl(int, int *);
+PCP_CALL extern int pmSetDerivedControl(int, int);
+
+/*
+ * pm{Get,Set}DerivedControl() information types ...
+ */
+#define PCP_DERIVED_GLOBAL_LIMIT	1
+#define PCP_DERIVED_CONTEXT_LIMIT	2
+#define PCP_DERIVED_DEBUG_SYNTAX	3
+#define PCP_DERIVED_DEBUG_SEMANTICS	4
+#define PCP_DERIVED_DEBUG_EVAL		5
 
 /*
  * Event Record support
